@@ -14,10 +14,10 @@ import pandas as pd
 
 
 
-import CIG.cig_network as cig
-import IT_nil.nil as nil
-import IT_node.IT_node as IT_node
-import IT.Interval_Tree as Interval_Tree
+from src.CIG import cig_network as cig
+from src.IT_nil import nil
+from src.IT_node import IT_node
+from src.IT import Interval_Tree
 
 
 
